`timescale 1ns/10ps

module test;
parameter CLK_PER = 100;
integer i, j;
reg [15:0] coef_pool[0:26];
reg [15:0] input_pool[0:100000];
reg [15:0] delayline[0:26];
reg clk;
reg rst;
reg [15:0] in1;
reg [15:0] in2;
reg [15:0] coef;
wire [15:0] acc;

AMA u_ama(
  .clk(clk),
  .rst(rst),
  .in1(in1),
  .in2(in2),
  .coef(coef),
  .Acc(acc)
);

always #(CLK_PER/2) clk = ~clk;

`ifdef FSDB
initial
begin
  $fsdbDumpvars;
  $fsdbDumpfile("test.fsdb");
end
`endif

`ifdef VCD
initial
begin
  $dumpvars(0, u_ama);
  $dumpfile("test.vcd");
end
`endif

`ifdef SDFTC
initial
begin
  $sdf_annotate("./AMA_tc.sdf", u_ama);
end
`endif

initial
begin

  $readmemh("coef.txt", coef_pool);
  $readmemh("sample_in.txt", input_pool);
//  $readmemh("speech_hex.txt", input_pool);
  for (i = 0; i < 27; i = i + 1)
  begin
    delayline[i] = 0;
  end

  clk = 0;
  rst = 1;
  #(CLK_PER);

  //for (j = 0; j < 100000; j = j + 1)
  for (j = 0; j < 46532; j = j + 1)
  begin

    rst = 1;
    #(CLK_PER);
    rst = 0;

    for (i = 26; i >= 1; i = i - 1)
    begin
      delayline[i] = delayline[i - 1];
      //$display("coef[%d]= %x",i, coef_pool[i]);
    end
    delayline[0] = input_pool[j];

    for (i = 0; i < 13; i = i + 1)
    begin
      in1 = delayline[i];
      in2 = delayline[27 - i - 1];
      coef = coef_pool[i];
      #(CLK_PER);
    end

    in1 = delayline[13];
    in2 = 16'h0000;
    coef = coef_pool[i];

    #(CLK_PER);
    $display("j=%d, out=%x", j, acc);
  end

  $finish;
end


endmodule
